@@ -79,7 +79,7 @@ this method returns a resultset that finds zero rows.
 sub chain_query_search_rs {
   my ($self, $Rs, $opt) = @_;
   
-  ... 
+  die "Unimplemented";
 }
 
 
@@ -138,4 +138,4 @@ sub searchbox_ext_config {
 
 
 
-1;
\ No newline at end of file
+1;
